# eric7.Plugins.VcsPlugins.vcsMercurial.StripExtension.HgStripDialog

Module implementing a dialog to enter the data to strip changesets.

### Global Attributes

None

### Classes

HgStripDialog | Class implementing a dialog to enter the data to strip changesets.

### Functions

None

## HgStripDialog

Class implementing a dialog to enter the data to strip changesets.

### Derived from

QDialog, Ui_HgStripDialog

### Class Attributes

None

### Class Methods

None

### Methods

HgStripDialog | Constructor
__getRevision | Private method to generate the revision.
__updateOK | Private slot to update the OK button.
getData | Public method to retrieve the data for the strip action.
on_branchButton_toggled | Private slot to handle changes of the Branch select button.
on_branchCombo_editTextChanged | Private slot to handle changes of the Branch combo.
on_idButton_toggled | Private slot to handle changes of the ID select button.
on_idEdit_textChanged | Private slot to handle changes of the ID edit.
on_numberButton_toggled | Private slot to handle changes of the Number select button.
on_numberSpinBox_valueChanged | Private slot to handle changes of the Number spin box.
on_tagButton_toggled | Private slot to handle changes of the Tag select button.
on_tagCombo_editTextChanged | Private slot to handle changes of the Tag combo.

### Static Methods

None

#### HgStripDialog (Constructor)

HgStripDialog(tagsList, branchesList, bookmarksList=None, rev="", parent=None)

Constructor

tagsList (list of str)
  list of tags
branchesList (list of str)
  list of branches
bookmarksList (list of str)
  list of bookmarks
rev (str)
  revision to strip from
parent (QWidget)
  reference to the parent widget

#### HgStripDialog.__getRevision

__getRevision()

Private method to generate the revision.

Return:
  revision

Return Type:
  str

#### HgStripDialog.__updateOK

__updateOK()

Private slot to update the OK button.

#### HgStripDialog.getData

getData()

Public method to retrieve the data for the strip action.

Return:
  tuple with the revision, a bookmark name, a flag indicating to enforce the strip action, a flag indicating to omit the creation of backup bundles and a flag indicating to not modify the working directory

Return Type:
  tuple (str, str, bool, bool, bool)

#### HgStripDialog.on_branchButton_toggled

on_branchButton_toggled(checked)

Private slot to handle changes of the Branch select button.

checked (bool)
  state of the button

#### HgStripDialog.on_branchCombo_editTextChanged

on_branchCombo_editTextChanged(txt)

Private slot to handle changes of the Branch combo.

txt (str)
  text of the combo

#### HgStripDialog.on_idButton_toggled

on_idButton_toggled(checked)

Private slot to handle changes of the ID select button.

checked (bool)
  state of the button

#### HgStripDialog.on_idEdit_textChanged

on_idEdit_textChanged(txt)

Private slot to handle changes of the ID edit.

txt (str)
  text of the edit

#### HgStripDialog.on_numberButton_toggled

on_numberButton_toggled(checked)

Private slot to handle changes of the Number select button.

checked (bool)
  state of the button

#### HgStripDialog.on_numberSpinBox_valueChanged

on_numberSpinBox_valueChanged(val)

Private slot to handle changes of the Number spin box.

val (int)
  value of the spin box

#### HgStripDialog.on_tagButton_toggled

on_tagButton_toggled(checked)

Private slot to handle changes of the Tag select button.

checked (bool)
  state of the button

#### HgStripDialog.on_tagCombo_editTextChanged

on_tagCombo_editTextChanged(txt)

Private slot to handle changes of the Tag combo.

txt (str)
  text of the combo

Up